@@ -104,35 +104,26 @@ test_that("safe_build_package calls pkgbuild with appropriate arguments", {
 
 test_that("should_error_for_warnings works", {
 
-  # If both unset, should error -> TRUE
-  withr::with_envvar(c("R_REMOTES_NO_ERRORS_FROM_WARNINGS" = NA, "_R_CHECK_FORCE_SUGGESTS_" = NA),
+  # If unset, should error -> false
+  withr::with_envvar(c("R_REMOTES_NO_ERRORS_FROM_WARNINGS" = NA),
+    expect_false(should_error_for_warnings())
+  )
+
+  # If set to true, should error -> false
+  withr::with_envvar(c("R_REMOTES_NO_ERRORS_FROM_WARNINGS" = "true"),
+    expect_false(should_error_for_warnings())
+  )
+  withr::with_envvar(c("R_REMOTES_NO_ERRORS_FROM_WARNINGS" = "1"),
+    expect_false(should_error_for_warnings())
+  )
+
+  # If set to true, should error -> true
+  withr::with_envvar(c("R_REMOTES_NO_ERRORS_FROM_WARNINGS" = "false"),
     expect_true(should_error_for_warnings())
   )
-
-  # If no errors true, should error -> FALSE
-  withr::with_envvar(c("R_REMOTES_NO_ERRORS_FROM_WARNINGS" = "true", "_R_CHECK_FORCE_SUGGESTS_" = NA),
-    expect_false(should_error_for_warnings())
-  )
-  withr::with_envvar(c("R_REMOTES_NO_ERRORS_FROM_WARNINGS" = "1", "_R_CHECK_FORCE_SUGGESTS_" = NA),
-    expect_false(should_error_for_warnings())
-  )
-
-  # If no errors unset, and force_suggests false, should error -> FALSE
-  withr::with_envvar(c("R_REMOTES_NO_ERRORS_FROM_WARNINGS" = NA, "_R_CHECK_FORCE_SUGGESTS_" = "false"),
-    expect_false(should_error_for_warnings())
-  )
-  withr::with_envvar(c("R_REMOTES_NO_ERRORS_FROM_WARNINGS" = NA, "_R_CHECK_FORCE_SUGGESTS_" = "0"),
-    expect_false(should_error_for_warnings())
-  )
-
-  # If no errors unset, and force_suggests true, should error -> TRUE
-  withr::with_envvar(c("R_REMOTES_NO_ERRORS_FROM_WARNINGS" = NA, "_R_CHECK_FORCE_SUGGESTS_" = "true"),
+  withr::with_envvar(c("R_REMOTES_NO_ERRORS_FROM_WARNINGS" = "0"),
     expect_true(should_error_for_warnings())
   )
-  withr::with_envvar(c("R_REMOTES_NO_ERRORS_FROM_WARNINGS" = NA, "_R_CHECK_FORCE_SUGGESTS_" = "1"),
-    expect_true(should_error_for_warnings())
-  )
-
 })
 
 test_that("normalize_build_opts works", {
